@@ -142,10 +142,16 @@ from diffpy.utils.diffraction_objects import XQUANTITIES, DiffractionObject
     ],
 )
 def test_diffraction_objects_equality(
-    do_args_1, do_args_2, expected_equality, wavelength_warning_expected, wavelength_warning_msg
+    do_args_1,
+    do_args_2,
+    expected_equality,
+    wavelength_warning_expected,
+    wavelength_warning_msg,
 ):
     if wavelength_warning_expected:
-        with pytest.warns(UserWarning, match=re.escape(wavelength_warning_msg)):
+        with pytest.warns(
+            UserWarning, match=re.escape(wavelength_warning_msg)
+        ):
             do_1 = DiffractionObject(**do_args_1)
             do_2 = DiffractionObject(**do_args_2)
     else:
@@ -184,14 +190,20 @@ def test_init_invalid_xtype():
             f"Please rerun specifying an xtype from {*XQUANTITIES, }"
         ),
     ):
-        return DiffractionObject(xarray=np.empty(0), yarray=np.empty(0), xtype="invalid_type", wavelength=1.54)
+        return DiffractionObject(
+            xarray=np.empty(0),
+            yarray=np.empty(0),
+            xtype="invalid_type",
+            wavelength=1.54,
+        )
 
 
 @pytest.mark.parametrize(
     "org_do_args, target_do_args, scale_inputs, expected",
     [
         # Test whether the original y-array is scaled as expected
-        (  # C1: none of q, tth, d, provided, expect to scale on the maximal intensity from each object
+        (  # C1: none of q, tth, d, provided, expect to scale on the maximal
+            # intensity from each object
             {
                 "xarray": np.array([0.1, 0.2, 0.3]),
                 "yarray": np.array([1, 2, 3]),
@@ -264,8 +276,8 @@ def test_init_invalid_xtype():
             {"tth": 60},
             {"xtype": "tth", "yarray": np.array([1, 2, 3, 4, 5, 6, 10])},
         ),
-        (  # C5.1: Reuse test case from C1, none of q, tth, d, provided, but include an offset,
-            # expect scaled y-array in C1 to shift up by 2
+        (  # C5.1: Reuse test case from C1, none of q, tth, d, provided, but
+            # include an offset, expect scaled y-array in C1 to shift up by 2
             {
                 "xarray": np.array([0.1, 0.2, 0.3]),
                 "yarray": np.array([1, 2, 3]),
@@ -281,7 +293,8 @@ def test_init_invalid_xtype():
             {"offset": 2},
             {"xtype": "q", "yarray": np.array([12, 22, 32])},
         ),
-        (  # C5.2: Reuse test case from C4, but include an offset, expect scaled y-array in C4 to shift up by 2
+        (  # C5.2: Reuse test case from C4, but include an offset, expect
+            # scaled y-array in C4 to shift up by 2
             {
                 "xarray": np.array([10, 25, 30.1, 40.2, 61, 120, 140]),
                 "yarray": np.array([10, 20, 30, 40, 50, 60, 100]),
@@ -304,7 +317,9 @@ def test_scale_to(org_do_args, target_do_args, scale_inputs, expected):
     target_do = DiffractionObject(**target_do_args)
     scaled_do = original_do.scale_to(target_do, **scale_inputs)
     # Check the intensity data is the same as expected
-    assert np.allclose(scaled_do.on_xtype(expected["xtype"])[1], expected["yarray"])
+    assert np.allclose(
+        scaled_do.on_xtype(expected["xtype"])[1], expected["yarray"]
+    )
 
 
 @pytest.mark.parametrize(
@@ -345,8 +360,10 @@ def test_scale_to_bad(org_do_args, target_do_args, scale_inputs):
 @pytest.mark.parametrize(
     "do_args, get_array_index_inputs, expected_index",
     [
-        # Test get_array_index() returns the expected index given xtype and value
-        (  # C1: Target value is in the xarray and xtype is identical, expect exact index match
+        # Test get_array_index() returns the expected index given xtype and
+        # value
+        (  # C1: Target value is in the xarray and xtype is identical, expect
+            # exact index match
             {
                 "wavelength": 4 * np.pi,
                 "xarray": np.array([30.005, 60]),
@@ -359,7 +376,8 @@ def test_scale_to_bad(org_do_args, target_do_args, scale_inputs):
             },
             0,
         ),
-        (  # C2: Target value lies in the array, expect the (first) closest index
+        # C2: Target value lies in the array, expect the closest index
+        (  # 1. xtype(tth) is equal to self._input_xtype(tth)
             {
                 "wavelength": 4 * np.pi,
                 "xarray": np.array([30, 60]),
@@ -372,7 +390,20 @@ def test_scale_to_bad(org_do_args, target_do_args, scale_inputs):
             },
             0,
         ),
-        (
+        (  # 2. use default xtype(equal to self._input_xtype)
+            {
+                "wavelength": 4 * np.pi,
+                "xarray": np.array([30, 60]),
+                "yarray": np.array([1, 2]),
+                "xtype": "tth",
+            },
+            {
+                "xtype": None,
+                "value": 45,
+            },
+            0,
+        ),
+        (  # 3. xtype(q) is different from self._input_xtype(tth)
             {
                 "wavelength": 4 * np.pi,
                 "xarray": np.array([30, 60]),
@@ -381,9 +412,9 @@ def test_scale_to_bad(org_do_args, target_do_args, scale_inputs):
             },
             {
                 "xtype": "q",
-                "value": 0.25,
+                "value": 0.5,
             },
-            0,
+            1,
         ),
         # C3: Target value out of the range, expect the closest index
         (  # 1. Test with xtype of "q"
@@ -416,21 +447,52 @@ def test_scale_to_bad(org_do_args, target_do_args, scale_inputs):
 )
 def test_get_array_index(do_args, get_array_index_inputs, expected_index):
     do = DiffractionObject(**do_args)
-    actual_index = do.get_array_index(get_array_index_inputs["xtype"], get_array_index_inputs["value"])
+    actual_index = do.get_array_index(
+        get_array_index_inputs["value"], get_array_index_inputs["xtype"]
+    )
     assert actual_index == expected_index
 
 
 def test_get_array_index_bad():
-    do = DiffractionObject(wavelength=2 * np.pi, xarray=np.array([]), yarray=np.array([]), xtype="tth")
-    with pytest.raises(ValueError, match=re.escape("The 'tth' array is empty. Please ensure it is initialized.")):
+    # empty array in DiffractionObject
+    do = DiffractionObject(
+        wavelength=2 * np.pi,
+        xarray=np.array([]),
+        yarray=np.array([]),
+        xtype="tth",
+    )
+    with pytest.raises(
+        ValueError,
+        match=re.escape(
+            "The 'tth' array is empty. Please ensure it is initialized."
+        ),
+    ):
         do.get_array_index(xtype="tth", xvalue=30)
+    # non-existing xtype
+    do = DiffractionObject(
+        wavelength=4 * np.pi,
+        xarray=np.array([30, 60]),
+        yarray=np.array([1, 2]),
+        xtype="tth",
+    )
+    non_existing_xtype = "non_existing_xtype"
+    with pytest.raises(
+        ValueError,
+        match=re.escape(
+            f"I don't know how to handle the xtype, '{non_existing_xtype}'. "
+            f"Please rerun specifying an xtype from {*XQUANTITIES, }"
+        ),
+    ):
+        do.get_array_index(xtype=non_existing_xtype, xvalue=30)
 
 
 def test_dump(tmp_path, mocker):
     x, y = np.linspace(0, 5, 6), np.linspace(0, 5, 6)
     directory = Path(tmp_path)
     file = directory / "testfile"
-    with pytest.warns(RuntimeWarning, match="divide by zero encountered in divide"):
+    with pytest.warns(
+        RuntimeWarning, match="divide by zero encountered in divide"
+    ):
         do = DiffractionObject(
             wavelength=1.54,
             name="test",
@@ -438,7 +500,11 @@ def test_dump(tmp_path, mocker):
             xarray=np.array(x),
             yarray=np.array(y),
             xtype="q",
-            metadata={"thing1": 1, "thing2": "thing2", "package_info": {"package2": "3.4.5"}},
+            metadata={
+                "thing1": 1,
+                "thing2": "thing2",
+                "package_info": {"package2": "3.4.5"},
+            },
         )
     mocker.patch("importlib.metadata.version", return_value="3.3.0")
     with freeze_time("2012-01-14"):
@@ -446,8 +512,13 @@ def test_dump(tmp_path, mocker):
     with open(file, "r") as f:
         actual = f.read()
     expected = (
-        "[DiffractionObject]\nname = test\nwavelength = 1.54\nscat_quantity = x-ray\nthing1 = 1\n"
-        "thing2 = thing2\npackage_info = {'package2': '3.4.5', 'diffpy.utils': '3.3.0'}\n"
+        "[DiffractionObject]\n"
+        "name = test\n"
+        "wavelength = 1.54\n"
+        "scat_quantity = x-ray\n"
+        "thing1 = 1\n"
+        "thing2 = thing2\n"
+        "package_info = {'package2': '3.4.5', 'diffpy.utils': '3.3.0'}\n"
         "creation_time = 2012-01-14 00:00:00\n\n"
         "#### start data\n0.000000000000000000e+00 0.000000000000000000e+00\n"
         "1.000000000000000000e+00 1.000000000000000000e+00\n"
@@ -461,10 +532,15 @@ def test_dump(tmp_path, mocker):
 
 
 @pytest.mark.parametrize(
-    "do_init_args, expected_do_dict, divide_by_zero_warning_expected, wavelength_warning_expected",
+    (
+        "do_init_args, expected_do_dict, "
+        "divide_by_zero_warning_expected, wavelength_warning_expected"
+    ),
     [
-        # Test __dict__ of DiffractionObject instance initialized with valid arguments
-        (  # C1: Instantiate DO with empty arrays, expect it to be a valid DO, but with everything empty
+        # Test __dict__ of DiffractionObject instance initialized with valid
+        # arguments
+        (  # C1: Instantiate DO with empty arrays, expect it to be a valid DO,
+            # but with everything empty
             {
                 "xarray": np.empty(0),
                 "yarray": np.empty(0),
@@ -487,8 +563,9 @@ def test_dump(tmp_path, mocker):
             False,
             True,
         ),
-        (  # C2: Instantiate just DO with empty array like in C1 but with wavelength, xtype, name, and metadata
-            # expect a valid DO with empty arrays, but with some non-array attributes
+        (  # C2: Instantiate just DO with empty array like in C1 but with
+            # wavelength, xtype, name, and metadata expect a valid DO with
+            # empty arrays, but with some non-array attributes
             {
                 "xarray": np.empty(0),
                 "yarray": np.empty(0),
@@ -514,8 +591,9 @@ def test_dump(tmp_path, mocker):
             False,
             False,
         ),
-        (  # C3: Minimum arguments provided for init with non-empty values for xarray and yarray and wavelength
-            # expect all attributes set without None
+        (  # C3: Minimum arguments provided for init with non-empty values
+            # for xarray and yarray and wavelength expect all attributes set
+            # without None
             {
                 "xarray": np.array([0.0, 90.0, 180.0]),
                 "yarray": np.array([1.0, 2.0, 3.0]),
@@ -545,9 +623,12 @@ def test_dump(tmp_path, mocker):
             True,
             False,
         ),
-        (  # C4: Same as C3, but with an optional scat_quantity argument, expect non-empty string for scat_quantity
+        (  # C4: Same as C3, but with an optional scat_quantity argument,
+            # expect non-empty string for scat_quantity
             {
-                "xarray": np.array([np.inf, 2 * np.sqrt(2) * np.pi, 2 * np.pi]),
+                "xarray": np.array(
+                    [np.inf, 2 * np.sqrt(2) * np.pi, 2 * np.pi]
+                ),
                 "yarray": np.array([1.0, 2.0, 3.0]),
                 "xtype": "d",
                 "wavelength": 4.0 * np.pi,
@@ -586,15 +667,23 @@ def test_init_valid(
     wavelength_warning_msg,
 ):
     if divide_by_zero_warning_expected:
-        with pytest.warns(RuntimeWarning, match="divide by zero encountered in divide"):
+        with pytest.warns(
+            RuntimeWarning, match="divide by zero encountered in divide"
+        ):
             actual_do_dict = DiffractionObject(**do_init_args).__dict__
     elif wavelength_warning_expected:
-        with pytest.warns(UserWarning, match=re.escape(wavelength_warning_msg)):
+        with pytest.warns(
+            UserWarning, match=re.escape(wavelength_warning_msg)
+        ):
             actual_do_dict = DiffractionObject(**do_init_args).__dict__
     else:
         actual_do_dict = DiffractionObject(**do_init_args).__dict__
     diff = DeepDiff(
-        actual_do_dict, expected_do_dict, ignore_order=True, significant_digits=13, exclude_paths="root['_uuid']"
+        actual_do_dict,
+        expected_do_dict,
+        ignore_order=True,
+        significant_digits=13,
+        exclude_paths="root['_uuid']",
     )
     assert diff == {}
 
@@ -602,12 +691,18 @@ def test_init_valid(
 @pytest.mark.parametrize(
     "do_init_args, expected_error_msg",
     [
-        # Test expected error messages when 3 required arguments not provided in DiffractionObject init
-        (  # C1: No arguments provided, expect 3 required positional arguments error
+        # Test expected error messages when 3 required arguments not provided
+        # in DiffractionObject init
+        (  # C1: No arguments provided, expect 3 required positional
+            # arguments error
             {},
-            "missing 3 required positional arguments: 'xarray', 'yarray', and 'xtype'",
+            (
+                "missing 3 required positional arguments: "
+                "'xarray', 'yarray', and 'xtype'"
+            ),
         ),
-        (  # C2: Only xarray and yarray provided, expect 1 required positional argument error
+        (  # C2: Only xarray and yarray provided, expect 1 required
+            # positional argument error
             {"xarray": np.array([0.0, 90.0]), "yarray": np.array([0.0, 90.0])},
             "missing 1 required positional argument: 'xtype'",
         ),
@@ -624,7 +719,10 @@ def test_init_invalid_args(
 def test_all_array_getter(do_minimal_tth):
     actual_do = do_minimal_tth
     print(actual_do.all_arrays)
-    expected_all_arrays = [[1, 0.51763809, 30, 12.13818192], [2, 1, 60, 6.28318531]]
+    expected_all_arrays = [
+        [1, 0.51763809, 30, 12.13818192],
+        [2, 1, 60, 6.28318531],
+    ]
     assert np.allclose(actual_do.all_arrays, expected_all_arrays)
 
 
@@ -647,7 +745,9 @@ def test_uuid_getter(do_minimal):
 
 def test_uuid_getter_with_mock(mocker, do_minimal):
     mocker.patch.object(
-        DiffractionObject, "uuid", new_callable=lambda: UUID("d67b19c6-3016-439f-81f7-cf20a04bee87")
+        DiffractionObject,
+        "uuid",
+        new_callable=lambda: UUID("d67b19c6-3016-439f-81f7-cf20a04bee87"),
     )
     do = do_minimal
     assert do.uuid == UUID("d67b19c6-3016-439f-81f7-cf20a04bee87")
@@ -658,7 +758,10 @@ def test_uuid_setter_error(do_minimal):
 
     with pytest.raises(
         AttributeError,
-        match="Direct modification of attribute 'uuid' is not allowed. Please use 'input_data' to modify 'uuid'.",
+        match=(
+            "Direct modification of attribute 'uuid' is not allowed. "
+            "Please use 'input_data' to modify 'uuid'."
+        ),
     ):
         do.uuid = uuid.uuid4()
 
@@ -671,7 +774,10 @@ def test_xarray_yarray_length_mismatch():
         "re-initialize 'DiffractionObject'with valid 'xarray' and 'yarray's",
     ):
         DiffractionObject(
-            xarray=np.array([1.0, 2.0]), yarray=np.array([0.0, 0.0, 0.0]), xtype="tth", wavelength=1.54
+            xarray=np.array([1.0, 2.0]),
+            yarray=np.array([0.0, 0.0, 0.0]),
+            xtype="tth",
+            wavelength=1.54,
         )
 
 
@@ -700,8 +806,10 @@ def test_copy_object(do_minimal):
 @pytest.mark.parametrize(
     "operation, starting_yarray, scalar_value, expected_yarray",
     [
-        # Test scalar addition, subtraction, multiplication, and division to y-values by adding a scalar value
-        # C1: Test scalar addition to y-values (intensity), expect no change to x-values (q, tth, d)
+        # Test scalar addition, subtraction, multiplication, and division to
+        # y-values by adding a scalar value
+        # C1: Test scalar addition to y-values (intensity), expect no change
+        # to x-values (q, tth, d)
         (  # 1. Add 5
             "add",
             np.array([1.0, 2.0]),
@@ -714,7 +822,8 @@ def test_copy_object(do_minimal):
             5.1,
             np.array([6.1, 7.1]),
         ),
-        # C2: Test scalar subtraction to y-values (intensity), expect no change to x-values (q, tth, d)
+        # C2: Test scalar subtraction to y-values (intensity), expect no
+        # change to x-values (q, tth, d)
         (  # 1. Subtract 1
             "sub",
             np.array([1.0, 2.0]),
@@ -727,7 +836,8 @@ def test_copy_object(do_minimal):
             0.5,
             np.array([0.5, 1.5]),
         ),
-        # C3: Test scalar multiplication to y-values (intensity), expect no change to x-values (q, tth, d)
+        # C3: Test scalar multiplication to y-values (intensity), expect no
+        # change to x-values (q, tth, d)
         (  # 1. Multiply by 2
             "mul",
             np.array([1.0, 2.0]),
@@ -740,7 +850,8 @@ def test_copy_object(do_minimal):
             2.5,
             np.array([2.5, 5.0]),
         ),
-        # C4: Test scalar division to y-values (intensity), expect no change to x-values (q, tth, d)
+        # C4: Test scalar division to y-values (intensity), expect no change
+        # to x-values (q, tth, d)
         (  # 1. Divide by 2
             "div",
             np.array([1.0, 2.0]),
@@ -755,9 +866,13 @@ def test_copy_object(do_minimal):
         ),
     ],
 )
-def test_scalar_operations(operation, starting_yarray, scalar_value, expected_yarray, do_minimal_tth):
+def test_scalar_operations(
+    operation, starting_yarray, scalar_value, expected_yarray, do_minimal_tth
+):
     do = do_minimal_tth
-    expected_xarray_constant = np.array([[0.51763809, 30.0, 12.13818192], [1.0, 60.0, 6.28318531]])
+    expected_xarray_constant = np.array(
+        [[0.51763809, 30.0, 12.13818192], [1.0, 60.0, 6.28318531]]
+    )
     assert np.allclose(do.all_arrays[:, [1, 2, 3]], expected_xarray_constant)
     assert np.allclose(do.all_arrays[:, 0], starting_yarray)
     if operation == "add":
@@ -775,33 +890,83 @@ def test_scalar_operations(operation, starting_yarray, scalar_value, expected_ya
     assert np.allclose(do_right_op.all_arrays[:, 0], expected_yarray)
     assert np.allclose(do_left_op.all_arrays[:, 0], expected_yarray)
     # Ensure x-values are unchanged
-    assert np.allclose(do_right_op.all_arrays[:, [1, 2, 3]], expected_xarray_constant)
-    assert np.allclose(do_left_op.all_arrays[:, [1, 2, 3]], expected_xarray_constant)
+    assert np.allclose(
+        do_right_op.all_arrays[:, [1, 2, 3]], expected_xarray_constant
+    )
+    assert np.allclose(
+        do_left_op.all_arrays[:, [1, 2, 3]], expected_xarray_constant
+    )
 
 
 @pytest.mark.parametrize(
-    "operation, expected_do_1_all_arrays_with_y_modified, expected_do_2_all_arrays_with_y_modified",
+    (
+        "operation, expected_do_1_all_arrays_with_y_modified, "
+        "expected_do_2_all_arrays_with_y_modified"
+    ),
     [
-        # Test addition, subtraction, multiplication, and division of two DO objects
+        # Test addition, subtraction, multiplication, and division of two DO
+        # objects
         (  # Test addition of two DO objects, expect combined yarray values
             "add",
-            np.array([[2.0, 0.51763809, 30.0, 12.13818192], [4.0, 1.0, 60.0, 6.28318531]]),
-            np.array([[2.0, 0.51763809, 30.0, 12.13818192], [4.0, 1.0, 60.0, 6.28318531]]),
+            np.array(
+                [
+                    [2.0, 0.51763809, 30.0, 12.13818192],
+                    [4.0, 1.0, 60.0, 6.28318531],
+                ]
+            ),
+            np.array(
+                [
+                    [2.0, 0.51763809, 30.0, 12.13818192],
+                    [4.0, 1.0, 60.0, 6.28318531],
+                ]
+            ),
         ),
-        (  # Test subtraction of two DO objects, expect differences in yarray values
+        (  # Test subtraction of two DO objects, expect differences in yarray
+            # values
             "sub",
-            np.array([[0.0, 0.51763809, 30.0, 12.13818192], [0.0, 1.0, 60.0, 6.28318531]]),
-            np.array([[0.0, 0.51763809, 30.0, 12.13818192], [0.0, 1.0, 60.0, 6.28318531]]),
+            np.array(
+                [
+                    [0.0, 0.51763809, 30.0, 12.13818192],
+                    [0.0, 1.0, 60.0, 6.28318531],
+                ]
+            ),
+            np.array(
+                [
+                    [0.0, 0.51763809, 30.0, 12.13818192],
+                    [0.0, 1.0, 60.0, 6.28318531],
+                ]
+            ),
         ),
-        (  # Test multiplication of two DO objects, expect multiplication in yarray values
+        (  # Test multiplication of two DO objects, expect multiplication in
+            # yarray values
             "mul",
-            np.array([[1.0, 0.51763809, 30.0, 12.13818192], [4.0, 1.0, 60.0, 6.28318531]]),
-            np.array([[1.0, 0.51763809, 30.0, 12.13818192], [4.0, 1.0, 60.0, 6.28318531]]),
+            np.array(
+                [
+                    [1.0, 0.51763809, 30.0, 12.13818192],
+                    [4.0, 1.0, 60.0, 6.28318531],
+                ]
+            ),
+            np.array(
+                [
+                    [1.0, 0.51763809, 30.0, 12.13818192],
+                    [4.0, 1.0, 60.0, 6.28318531],
+                ]
+            ),
         ),
         (  # Test division of two DO objects, expect division in yarray values
             "div",
-            np.array([[1.0, 0.51763809, 30.0, 12.13818192], [1.0, 1.0, 60.0, 6.28318531]]),
-            np.array([[1.0, 0.51763809, 30.0, 12.13818192], [1.0, 1.0, 60.0, 6.28318531]]),
+            np.array(
+                [
+                    [1.0, 0.51763809, 30.0, 12.13818192],
+                    [1.0, 1.0, 60.0, 6.28318531],
+                ]
+            ),
+            np.array(
+                [
+                    [1.0, 0.51763809, 30.0, 12.13818192],
+                    [1.0, 1.0, 60.0, 6.28318531],
+                ]
+            ),
         ),
     ],
 )
@@ -814,10 +979,22 @@ def test_binary_operator_on_do(
     do_1 = do_minimal_tth
     do_2 = do_minimal_tth
     assert np.allclose(
-        do_1.all_arrays, np.array([[1.0, 0.51763809, 30.0, 12.13818192], [2.0, 1.0, 60.0, 6.28318531]])
+        do_1.all_arrays,
+        np.array(
+            [
+                [1.0, 0.51763809, 30.0, 12.13818192],
+                [2.0, 1.0, 60.0, 6.28318531],
+            ]
+        ),
     )
     assert np.allclose(
-        do_2.all_arrays, np.array([[1.0, 0.51763809, 30.0, 12.13818192], [2.0, 1.0, 60.0, 6.28318531]])
+        do_2.all_arrays,
+        np.array(
+            [
+                [1.0, 0.51763809, 30.0, 12.13818192],
+                [2.0, 1.0, 60.0, 6.28318531],
+            ]
+        ),
     )
 
     if operation == "add":
@@ -833,8 +1010,12 @@ def test_binary_operator_on_do(
         do_1_y_modified = do_1 / do_2
         do_2_y_modified = do_2 / do_1
 
-    assert np.allclose(do_1_y_modified.all_arrays, expected_do_1_all_arrays_with_y_modified)
-    assert np.allclose(do_2_y_modified.all_arrays, expected_do_2_all_arrays_with_y_modified)
+    assert np.allclose(
+        do_1_y_modified.all_arrays, expected_do_1_all_arrays_with_y_modified
+    )
+    assert np.allclose(
+        do_2_y_modified.all_arrays, expected_do_2_all_arrays_with_y_modified
+    )
 
 
 def test_operator_invalid_type(do_minimal_tth, invalid_add_type_error_msg):
@@ -848,9 +1029,13 @@ def test_operator_invalid_type(do_minimal_tth, invalid_add_type_error_msg):
         (lambda x, y: x / y),  # Test division
     ]
     for operation in operations:
-        with pytest.raises(TypeError, match=re.escape(invalid_add_type_error_msg)):
+        with pytest.raises(
+            TypeError, match=re.escape(invalid_add_type_error_msg)
+        ):
             operation(do, invalid_value)
-        with pytest.raises(TypeError, match=re.escape(invalid_add_type_error_msg)):
+        with pytest.raises(
+            TypeError, match=re.escape(invalid_add_type_error_msg)
+        ):
             operation(invalid_value, do)
 
 
@@ -858,10 +1043,13 @@ def test_operator_invalid_type(do_minimal_tth, invalid_add_type_error_msg):
 def test_operator_invalid_xarray_values_not_equal(
     operation, do_minimal_tth, do_minimal_d, x_values_not_equal_error_msg
 ):
-    # Add two DO objects with different xarray values but equal in shape, expect ValueError
+    # Add two DO objects with different xarray values but equal in shape,
+    # expect ValueError
     do_1 = do_minimal_tth
     do_2 = do_minimal_d
-    with pytest.raises(ValueError, match=re.escape(x_values_not_equal_error_msg)):
+    with pytest.raises(
+        ValueError, match=re.escape(x_values_not_equal_error_msg)
+    ):
         if operation == "add":
             do_1 + do_2
         elif operation == "sub":
@@ -879,7 +1067,9 @@ def test_operator_invalid_xarray_shape_not_equal(
     # Add two DO objects with different xarrays shape, expect ValueError
     do_1 = do_minimal
     do_2 = do_minimal_tth
-    with pytest.raises(ValueError, match=re.escape(x_values_not_equal_error_msg)):
+    with pytest.raises(
+        ValueError, match=re.escape(x_values_not_equal_error_msg)
+    ):
         if operation == "add":
             do_1 + do_2
         elif operation == "sub":
