@@ -18,34 +18,64 @@ from diffpy.utils.tools import (
 
 @pytest.mark.parametrize(
     "runtime_inputs, expected",
-    [  # config file in home is present, no config in cwd.  various runtime values passed
+    [  # config file in home is present, no config in cwd.  various runtime
+        # values passed
         # C1: nothing passed in, expect uname, email, orcid from home_config
-        ({}, {"owner_name": "home_ownername", "owner_email": "home@email.com", "owner_orcid": "home_orcid"}),
-        # C2: empty strings passed in, expect uname, email, orcid from home_config
+        (
+            {},
+            {
+                "owner_name": "home_ownername",
+                "owner_email": "home@email.com",
+                "owner_orcid": "home_orcid",
+            },
+        ),
+        # C2: empty strings passed in, expect uname, email, orcid from
+        # home_config
         (
             {"owner_name": "", "owner_email": "", "owner_orcid": ""},
-            {"owner_name": "home_ownername", "owner_email": "home@email.com", "owner_orcid": "home_orcid"},
+            {
+                "owner_name": "home_ownername",
+                "owner_email": "home@email.com",
+                "owner_orcid": "home_orcid",
+            },
         ),
-        # C3: just owner name passed in at runtime.  expect runtime_oname but others from config
+        # C3: just owner name passed in at runtime.  expect runtime_oname but
+        # others from config
         (
             {"owner_name": "runtime_ownername"},
-            {"owner_name": "runtime_ownername", "owner_email": "home@email.com", "owner_orcid": "home_orcid"},
+            {
+                "owner_name": "runtime_ownername",
+                "owner_email": "home@email.com",
+                "owner_orcid": "home_orcid",
+            },
         ),
-        # C4: just owner email passed in at runtime.  expect runtime_email but others from config
+        # C4: just owner email passed in at runtime.  expect runtime_email
+        # but others from config
         (
             {"owner_email": "runtime@email.com"},
-            {"owner_name": "home_ownername", "owner_email": "runtime@email.com", "owner_orcid": "home_orcid"},
+            {
+                "owner_name": "home_ownername",
+                "owner_email": "runtime@email.com",
+                "owner_orcid": "home_orcid",
+            },
         ),
-        # C5: just owner ci passed in at runtime.  expect runtime_orcid but others from config
+        # C5: just owner ci passed in at runtime.  expect runtime_orcid but
+        # others from config
         (
             {"owner_orcid": "runtime_orcid"},
-            {"owner_name": "home_ownername", "owner_email": "home@email.com", "owner_orcid": "runtime_orcid"},
+            {
+                "owner_name": "home_ownername",
+                "owner_email": "home@email.com",
+                "owner_orcid": "runtime_orcid",
+            },
         ),
     ],
 )
-def test_get_user_info_with_home_conf_file(runtime_inputs, expected, user_filesystem, mocker):
-    # user_filesystem[0] is tmp_dir/home_dir with the global config file in it, user_filesystem[1]
-    #   is tmp_dir/cwd_dir
+def test_get_user_info_with_home_conf_file(
+    runtime_inputs, expected, user_filesystem, mocker
+):
+    # user_filesystem[0] is tmp_dir/home_dir with the global config file in it,
+    #   user_filesystem[1] is tmp_dir/cwd_dir
     mocker.patch.object(Path, "home", return_value=user_filesystem[0])
     os.chdir(user_filesystem[1])
     actual = get_user_info(**runtime_inputs)
@@ -56,36 +86,69 @@ def test_get_user_info_with_home_conf_file(runtime_inputs, expected, user_filesy
     "runtime_inputs, expected",
     [  # tests as before but now config file present in cwd and home but orcid
         #   missing in the cwd config
-        # C1: nothing passed in, expect uname, email from local config, orcid from home_config
-        ({}, {"owner_name": "cwd_ownername", "owner_email": "cwd@email.com", "owner_orcid": "home_orcid"}),
-        # C2: empty strings passed in, expect uname, email, orcid from home_config
+        # C1: nothing passed in, expect uname, email from local config, orcid
+        # from home_config
+        (
+            {},
+            {
+                "owner_name": "cwd_ownername",
+                "owner_email": "cwd@email.com",
+                "owner_orcid": "home_orcid",
+            },
+        ),
+        # C2: empty strings passed in, expect uname, email, orcid from
+        # home_config
         (
             {"owner_name": "", "owner_email": "", "owner_orcid": ""},
-            {"owner_name": "cwd_ownername", "owner_email": "cwd@email.com", "owner_orcid": "home_orcid"},
+            {
+                "owner_name": "cwd_ownername",
+                "owner_email": "cwd@email.com",
+                "owner_orcid": "home_orcid",
+            },
         ),
-        # C3: just owner name passed in at runtime.  expect runtime_oname but others from config
+        # C3: just owner name passed in at runtime.  expect runtime_oname but
+        # others from config
         (
             {"owner_name": "runtime_ownername"},
-            {"owner_name": "runtime_ownername", "owner_email": "cwd@email.com", "owner_orcid": "home_orcid"},
+            {
+                "owner_name": "runtime_ownername",
+                "owner_email": "cwd@email.com",
+                "owner_orcid": "home_orcid",
+            },
         ),
-        # C4: just owner email passed in at runtime.  expect runtime_email but others from config
+        # C4: just owner email passed in at runtime.  expect runtime_email
+        # but others from config
         (
             {"owner_email": "runtime@email.com"},
-            {"owner_name": "cwd_ownername", "owner_email": "runtime@email.com", "owner_orcid": "home_orcid"},
+            {
+                "owner_name": "cwd_ownername",
+                "owner_email": "runtime@email.com",
+                "owner_orcid": "home_orcid",
+            },
         ),
-        # C5: just owner ci passed in at runtime.  expect runtime_orcid but others from config
+        # C5: just owner ci passed in at runtime.  expect runtime_orcid but
+        # others from config
         (
             {"owner_orcid": "runtime_orcid"},
-            {"owner_name": "cwd_ownername", "owner_email": "cwd@email.com", "owner_orcid": "runtime_orcid"},
+            {
+                "owner_name": "cwd_ownername",
+                "owner_email": "cwd@email.com",
+                "owner_orcid": "runtime_orcid",
+            },
         ),
     ],
 )
-def test_get_user_info_with_local_conf_file(runtime_inputs, expected, user_filesystem, mocker):
-    # user_filesystem[0] is tmp_dir/home_dir with the global config file in it, user_filesystem[1]
-    #   is tmp_dir/cwd_dir
+def test_get_user_info_with_local_conf_file(
+    runtime_inputs, expected, user_filesystem, mocker
+):
+    # user_filesystem[0] is tmp_dir/home_dir with the global config file in it,
+    #   user_filesystem[1] is tmp_dir/cwd_dir
     mocker.patch.object(Path, "home", return_value=user_filesystem[0])
     os.chdir(user_filesystem[1])
-    local_config_data = {"owner_name": "cwd_ownername", "owner_email": "cwd@email.com"}
+    local_config_data = {
+        "owner_name": "cwd_ownername",
+        "owner_email": "cwd@email.com",
+    }
     with open(user_filesystem[1] / "diffpyconfig.json", "w") as f:
         json.dump(local_config_data, f)
     actual = get_user_info(**runtime_inputs)
@@ -94,21 +157,32 @@ def test_get_user_info_with_local_conf_file(runtime_inputs, expected, user_files
 
 @pytest.mark.parametrize(
     "test_inputs,expected",
-    [  # Check check_and_build_global_config() builds correct config when config is found missing
+    [  # Check check_and_build_global_config() builds correct config when
+        #   config is found missing
         (  # C1: user inputs valid name, email and orcid
             {"user_inputs": ["input_name", "input@email.com", "input_orcid"]},
-            {"owner_email": "input@email.com", "owner_orcid": "input_orcid", "owner_name": "input_name"},
+            {
+                "owner_email": "input@email.com",
+                "owner_orcid": "input_orcid",
+                "owner_name": "input_name",
+            },
         ),
-        ({"user_inputs": ["", "", ""]}, None),  # C2: empty strings passed in, expect no config file created
-        (  # C3: just username input, expect config file but with some empty values
+        (
+            {"user_inputs": ["", "", ""]},
+            None,
+        ),  # C2: empty strings passed in, expect no config file created
+        (  # C3: just username input, expect config file but with some empty
+            # values
             {"user_inputs": ["input_name", "", ""]},
             {"owner_email": "", "owner_orcid": "", "owner_name": "input_name"},
         ),
     ],
 )
-def test_check_and_build_global_config(test_inputs, expected, user_filesystem, mocker):
-    # user_filesystem[0] is tmp_dir/home_dir with the global config file in it, user_filesystem[1]
-    #   is tmp_dir/cwd_dir
+def test_check_and_build_global_config(
+    test_inputs, expected, user_filesystem, mocker
+):
+    # user_filesystem[0] is tmp_dir/home_dir with the global config file in it,
+    #   user_filesystem[1] is tmp_dir/cwd_dir
     mocker.patch.object(Path, "home", return_value=user_filesystem[0])
     os.chdir(user_filesystem[1])
     confile = user_filesystem[0] / "diffpyconfig.json"
@@ -131,7 +205,11 @@ def test_check_and_build_global_config_file_exists(user_filesystem, mocker):
     mocker.patch.object(Path, "home", return_value=user_filesystem[0])
     os.chdir(user_filesystem[1])
     confile = user_filesystem[0] / "diffpyconfig.json"
-    expected = {"owner_name": "home_ownername", "owner_email": "home@email.com", "owner_orcid": "home_orcid"}
+    expected = {
+        "owner_name": "home_ownername",
+        "owner_email": "home@email.com",
+        "owner_orcid": "home_orcid",
+    }
     actual_bool = check_and_build_global_config()
     assert actual_bool is True
     with open(confile, "r") as f:
@@ -152,11 +230,29 @@ def test_check_and_build_global_config_skipped(user_filesystem, mocker):
 
 params_package_info = [
     (["diffpy.utils", None], {"package_info": {"diffpy.utils": "3.3.0"}}),
-    (["package1", None], {"package_info": {"package1": "1.2.3", "diffpy.utils": "3.3.0"}}),
-    (["package1", {"thing1": 1}], {"thing1": 1, "package_info": {"package1": "1.2.3", "diffpy.utils": "3.3.0"}}),
     (
-        ["package1", {"package_info": {"package1": "1.1.0", "package2": "3.4.5"}}],
-        {"package_info": {"package1": "1.2.3", "package2": "3.4.5", "diffpy.utils": "3.3.0"}},
+        ["package1", None],
+        {"package_info": {"package1": "1.2.3", "diffpy.utils": "3.3.0"}},
+    ),
+    (
+        ["package1", {"thing1": 1}],
+        {
+            "thing1": 1,
+            "package_info": {"package1": "1.2.3", "diffpy.utils": "3.3.0"},
+        },
+    ),
+    (
+        [
+            "package1",
+            {"package_info": {"package1": "1.1.0", "package2": "3.4.5"}},
+        ],
+        {
+            "package_info": {
+                "package1": "1.2.3",
+                "package2": "3.4.5",
+                "diffpy.utils": "3.3.0",
+            }
+        },
     ),
 ]
 
@@ -164,7 +260,11 @@ params_package_info = [
 @pytest.mark.parametrize("inputs, expected", params_package_info)
 def test_get_package_info(monkeypatch, inputs, expected):
     monkeypatch.setattr(
-        importlib.metadata, "version", lambda package_name: "3.3.0" if package_name == "diffpy.utils" else "1.2.3"
+        importlib.metadata,
+        "version",
+        lambda package_name: (
+            "3.3.0" if package_name == "diffpy.utils" else "1.2.3"
+        ),
     )
     actual_metadata = get_package_info(inputs[0], metadata=inputs[1])
     assert actual_metadata == expected
@@ -174,7 +274,8 @@ def test_get_package_info(monkeypatch, inputs, expected):
     "inputs",
     [
         # Test when the function has invalid inputs
-        (  # C1: Both mass density and packing fraction are provided, expect ValueError exception
+        (  # C1: Both mass density and packing fraction are provided,
+            # expect ValueError exception
             {
                 "sample_composition": "SiO2",
                 "energy": 10,
@@ -182,7 +283,8 @@ def test_get_package_info(monkeypatch, inputs, expected):
                 "packing_fraction": 1,
             }
         ),
-        (  # C2: None of mass density or packing fraction are provided, expect ValueError exception
+        (  # C2: None of mass density or packing fraction are provided,
+            # expect ValueError exception
             {
                 "sample_composition": "SiO2",
                 "energy": 10,
@@ -193,8 +295,11 @@ def test_get_package_info(monkeypatch, inputs, expected):
 def test_compute_mu_using_xraydb_bad(inputs):
     with pytest.raises(
         ValueError,
-        match="You must specify either sample_mass_density or packing_fraction, but not both. "
-        "Please rerun specifying only one.",
+        match=(
+            "You must specify either sample_mass_density or "
+            "packing_fraction, but not both. "
+            "Please rerun specifying only one."
+        ),
     ):
         compute_mu_using_xraydb(**inputs)
 
@@ -202,7 +307,9 @@ def test_compute_mu_using_xraydb_bad(inputs):
 def test_compute_mud(tmp_path):
     diameter, slit_width, z0, I0, mud, slope = 1, 0.1, 0, 1e5, 3, 0
     z_data = np.linspace(-1, 1, 50)
-    convolved_I_data = _extend_z_and_convolve(z_data, diameter, slit_width, z0, I0, mud, slope)
+    convolved_I_data = _extend_z_and_convolve(
+        z_data, diameter, slit_width, z0, I0, mud, slope
+    )
 
     directory = Path(tmp_path)
     file = directory / "testfile"
